@@ -107,7 +107,7 @@ pub mod stream;
 pub trait Key: Copy + Eq + Hash + Ord + std::fmt::Debug + std::fmt::Display + for<'de> Deserialize<'de> + Serialize {}
 impl<T> Key for T where T: Copy + Eq + Hash + Ord + std::fmt::Debug + std::fmt::Display + for<'de> Deserialize<'de> + Serialize {}
 
-const CURRENT_FORMAT_VERSION: u16 = 1;
+const CURRENT_FORMAT_VERSION: u16 = 2;
 
 fn codec() -> impl bincode::Options + Copy /* {{{ */ {
 	bincode::DefaultOptions::new()
@@ -309,10 +309,7 @@ where
 			.append(false)
 			.open(&self.path)
 			.await?;
-		let pos = SeekFrom::Start(self.data_start_position());
-		println!("pos = {:?}", pos);
-		file.seek(pos).await?;
-		println!("pair count = {}", self.header.pair_count);
+		file.seek(SeekFrom::Start(self.data_start_position())).await?;
 		let stream = stream::ValueStream::new(file).take(self.header.pair_count as usize);
 		Ok(stream)
 	} // }}}
